.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xnpy: read/write NPY files
==========================

Defined in ``xtensor/xnpy.hpp``

.. doxygenfunction:: xt::load_npy(std::istream&)
   :project: xtensor

.. doxygenfunction:: xt::load_npy(const std::string&)
   :project: xtensor

.. doxygenfunction:: xt::dump_npy(const std::string&, const xexpression<E>&)
   :project: xtensor

.. doxygenfunction:: xt::dump_npy(const xexpression<E>&)
   :project: xtensor
